/**
 * @packageDocumentation
 * @module String
 */
import { Observable, ObservableInput } from 'rxjs';
import { FormType } from '../types/normalize';
/**
 * Returns an Observable that emits a string made from a source unicode string using String.normalize
 *
 * @category String Observables
 *
 * @remarks This operator is a type-safe {@link https://rxjs.dev/api/index/function/from|from} and will emit only
 * strings, also unlike `from` a single string is not converted into an array-like.
 *
 * @param input A string or array of string unicode characters
 * @param form The Unicode Normalization Form to decode the string with
 *
 * @example
 * Returns a string from Unicode characters
 * ```ts
 * fromUnicode('\u0041\u006d\u00e9\u006c\u0069\u0065').subscribe();
 * ```
 * Output: `Amélie`
 *
 * @returns Observable that emits a string
 */
export declare function fromUnicode<T extends ObservableInput<string[]> | PromiseLike<string[]> | string | string[]>(input: T, form?: FormType): Observable<string>;
