/**
 * @packageDocumentation
 * @module String
 */
import { OperatorFunction } from 'rxjs';
/**
 * Returns an Observable that emits a string from a source of character codes using String.fromCharCode
 *
 * @category String Mapping
 *
 * @see The [[fromCharCode]] Observable can be used to generate a string source from character codes
 *
 * @example
 * Returns a string `RxJS` from a source array of character codes
 * ```ts
 * of([82, 120, 74, 83]).pipe(mapCharCode()).subscribe()
 * ```
 * Output: `RxJS`
 *
 *
 * @returns Observable that emits a string from source character codes
 */
export declare function mapCharCode(): OperatorFunction<number | number[], string>;
