/**
 * @packageDocumentation
 * @module String
 */
import { MonoTypeOperatorFunction } from 'rxjs';
/**
 * Returns an Observable that emits a string where the source string has any white space at the start removed using
 * String.trimStart
 *
 * @category String Modify
 *
 * @alias `trimLeft`
 *
 * @example
 * Returns the source string with any whitespace at the start removed
 * ```ts
 * of('  RxJS Ninja  ').pipe(trimStart()).subscribe();
 * ```
 * Output: `'RxJS Ninja  '`
 *
 * @returns Observable that emits a trimmed string
 */
export declare function trimStart(): MonoTypeOperatorFunction<string>;
/**
 * Returns an Observable that emits a string where the source string has any white space at the end removed using
 * String.trimEnd
 *
 * @category String Modify
 *
 * @alias `trimRight`
 *
 * @example
 * Returns the source string with any whitespace at the end removed
 * ```ts
 * of('  RxJS Ninja  ').pipe(trimStart()).subscribe();
 * ```
 * Output: `'  RxJS Ninja'`
 *
 * @returns Observable that emits a trimmed string
 */
export declare function trimEnd(): MonoTypeOperatorFunction<string>;
/**
 * Returns an Observable that emits a string where the source string has any white space at the ends removed using
 * String.trim
 *
 * @category String Modify
 *
 * @example
 * Returns the source string with any whitespace at both ends removed
 * ```ts
 * of('  RxJS Ninja  ').pipe(trimStart()).subscribe();
 * ```
 * Output: `'RxJS Ninja'`
 *
 * @returns Observable that emits a trimmed string
 */
export declare function trim(): MonoTypeOperatorFunction<string>;
